=======
History
=======

0.1.0 (2019-04-14)
------------------

* First super-unpolished and barely usable release on PyPI.


0.3.0 (2019-06-26)
------------------

* First real release on PyPI.


0.4.0 (2019-11-12)
------------------

* Fixed multipage OCR on PDFs
* Added Language as a command line option


0.5.0 (2019-11-14)
------------------

* Removed unidecode function on OCR, no longer needed
